



## Requirements: 

Python==3.9 | [PyTorch >= 1.12.0](https://pytorch.org/) | [TorchData](https://github.com/pytorch/data) | [TorchRec](https://github.com/pytorch/torchrec)


## Installation

    pip install freerec



## Reference Code

- TorchRec: https://github.com/pytorch/torchrec 
- DeepCTR-Torch: https://github.com/shenweichen/DeepCTR-Torch
- FuxiCTR: https://github.com/xue-pai/FuxiCTR
- BARS: https://github.com/openbenchmark/BARS
